MaybeInputsSeen

Struct MaybeInputsSeen 

pub struct MaybeInputsSeen { /* private fields */ }
Available on crate feature v1 only.
Typestate to check that the original PSBT has no inputs that the receiver has seen before.

Call Self::check_no_inputs_seen_before to proceed.

Implementations

Source

impl MaybeInputsSeen

pub fn check_no_inputs_seen_before( self, is_known: &mut impl FnMut(&OutPoint) -> Result<bool, ImplementationError>, ) -> Result<OutputsUnknown, Error>

Check that the receiver has never seen the inputs in the original proposal before.

This check prevents the following attacks:

  1. Probing attacks, where the sender can use the exact same proposal (or with minimal change) to have the receiver reveal their UTXO set by contributing to all proposals with different inputs and sending them back to the receiver.
  2. Re-entrant payjoin, where the sender uses the payjoin PSBT of a previous payjoin as the original proposal PSBT of the current, new payjoin.