pub struct ProvisionalProposal { /* private fields */ }Available on crate feature
v1 only.Expand description
Typestate for a checked proposal which had both the outputs and the inputs modified by the receiver. The receiver may sign and finalize the Payjoin proposal which will be sent to the sender for their signature.
Call Self::finalize_proposal to return a finalized PayjoinProposal.
Implementations
Sourceimpl ProvisionalProposal
impl ProvisionalProposal
Sourcepub fn finalize_proposal(
self,
wallet_process_psbt: impl Fn(&Psbt) -> Result<Psbt, ImplementationError>,
) -> Result<PayjoinProposal, Error>
pub fn finalize_proposal( self, wallet_process_psbt: impl Fn(&Psbt) -> Result<Psbt, ImplementationError>, ) -> Result<PayjoinProposal, Error>
Finalizes the Payjoin proposal into a PSBT which the sender will find acceptable before they sign the transaction and broadcast it to the network.
Finalization consists of two steps:
- Remove all sender signatures which were received with the original PSBT as these signatures are now invalid.
- Sign and finalize the resulting PSBT using the passed
wallet_process_psbtsigning function.
Sourcepub fn psbt_to_sign(&self) -> Psbt
pub fn psbt_to_sign(&self) -> Psbt
The Payjoin proposal PSBT that the receiver needs to sign
In some applications the entity that progresses the typestate is different from the entity that has access to the private keys, so the PSBT to sign must be accessible to such implementers.